==> coin2_2.5.0.orig.tar.gz: Coin-2.5.0/include/Inventor/nodes/SoShaderProgram.h <==
#ifndef COIN_SOSHADERPROGRAM_H
#define COIN_SOSHADERPROGRAM_H

/**************************************************************************\
 *
 *  This file is part of the Coin 3D visualization library.
 *  Copyright (C) 1998-2007 by Systems in Motion.  All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  ("GPL") version 2 as published by the Free Software Foundation.
 *  See the file LICENSE.GPL at the root directory of this source
 *  distribution for additional information about the GNU GPL.
 *
 *  For using Coin with software that can not be combined with the GNU
 *  GPL, and for taking advantage of the additional benefits of our
 *  support services, please contact Systems in Motion about acquiring
 *  a Coin Professional Edition License.
 *
 *  See http://www.coin3d.org/ for more information.
 *
 *  Systems in Motion, Postboks 1283, Pirsenteret, 7462 Trondheim, NORWAY.
 *  http://www.sim.no/  sales@sim.no  coin-support@coin3d.org
 *
\**************************************************************************/

#include <Inventor/nodes/SoNode.h>
#include <Inventor/nodes/SoSubNode.h>
#include <Inventor/fields/SoMFNode.h>

class SoState;
class SoGLRenderAction;


typedef void SoShaderProgramEnableCB(void * closure, 
                                     SoState * state,
                                     const SbBool enable);

// *************************************************************************

class COIN_DLL_API SoShaderProgram : public SoNode {
  typedef SoNode inherited;
  SO_NODE_HEADER(SoShaderProgram);

public:
  SoMFNode shaderObject;

  SoShaderProgram(void);

  void setEnableCallback(SoShaderProgramEnableCB * cb,
                         void * closure);

SoEXTENDER public:
  virtual void GLRender(SoGLRenderAction * action);
  virtual void search(SoSearchAction * action);

SoINTERNAL public:
  static void initClass();

protected:
  virtual ~SoShaderProgram();

private:
  class SoShaderProgramP * pimpl;
};

#endif /* ! COIN_SOSHADERPROGRAM_H */

==> coin3_3.0.0.orig.tar.gz: Coin-3.0.0/include/Inventor/nodes/SoShaderProgram.h <==
#ifndef COIN_SOSHADERPROGRAM_H
#define COIN_SOSHADERPROGRAM_H

/**************************************************************************\
 *
 *  This file is part of the Coin 3D visualization library.
 *  Copyright (C) 1998-2008 by Kongsberg SIM.  All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  ("GPL") version 2 as published by the Free Software Foundation.
 *  See the file LICENSE.GPL at the root directory of this source
 *  distribution for additional information about the GNU GPL.
 *
 *  For using Coin with software that can not be combined with the GNU
 *  GPL, and for taking advantage of the additional benefits of our
 *  support services, please contact Kongsberg SIM about acquiring
 *  a Coin Professional Edition License.
 *
 *  See http://www.coin3d.org/ for more information.
 *
 *  Kongsberg SIM, Postboks 1283, Pirsenteret, 7462 Trondheim, NORWAY.
 *  http://www.sim.no/  sales@sim.no  coin-support@coin3d.org
 *
\**************************************************************************/

#include <Inventor/nodes/SoNode.h>
#include <Inventor/nodes/SoSubNode.h>
#include <Inventor/fields/SoMFNode.h>

class SoState;
class SoGLRenderAction;


typedef void SoShaderProgramEnableCB(void * closure, 
                                     SoState * state,
                                     const SbBool enable);

// *************************************************************************

class COIN_DLL_API SoShaderProgram : public SoNode {
  typedef SoNode inherited;
  SO_NODE_HEADER(SoShaderProgram);

public:
  SoMFNode shaderObject;

  SoShaderProgram(void);

  void setEnableCallback(SoShaderProgramEnableCB * cb,
                         void * closure);

SoEXTENDER public:
  virtual void GLRender(SoGLRenderAction * action);
  virtual void search(SoSearchAction * action);

SoINTERNAL public:
  static void initClass();

protected:
  virtual ~SoShaderProgram();

private:
  class SoShaderProgramP * pimpl;
};

#endif /* ! COIN_SOSHADERPROGRAM_H */
